#
# spec file for package sapinit (Version 3.0)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           sapinit
BuildRequires:  grep procps sed
Version:        3.0
Release:        1.15.24
Summary:        Kernel Parameter Initializiation for SAP Systems
Group:          Productivity/Other
License:        GPL v2 or later
Url:            http://www.novell.com/partners/sap/
PreReq:         %insserv_prereq %fillup_prereq
PreReq:         /bin/awk /bin/grep /bin/mktemp /bin/mv /bin/sed
#%if %suse_version >= 1100
%if "%name" == "sapconf"
PreReq:         /bin/fsync
%endif
%if "%name" == "sapconf"
Provides:       suse-sapinit sapinit
Obsoletes:      suse-sapinit sapinit
%endif
%if %suse_version > 1000
Suggests:       cron logrotate
%endif
Requires:       sysstat
Conflicts:      ulimit
Source0:        boot.sapconf
Source1:        SAPconf
Source2:        functions
Source3:        config.b32
Source4:        config.b64
Source5:        LGPL
Source6:        README
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  %ix86 ia64 s390x ppc64 x86_64
%global         _libdir /%{_lib}

%description 
This package sets the kernel parameters to recommended values for SAP
systems in a dynamic way during boot time by using the sysctl(8) tool.

The kernel parameters can be changed by the user by editing the
variables in the configuration file /etc/sysconfig/sapinit.

Furthermore, it is checked that a well-sized /dev/shm is available for
the XSI shared memory facility.

On SLES9 systems the /dev/shm is mounted as an own tmpfs and therefore
an entry for /dev/shm in /etc/fstab is useful but not required.

On SLES10 systems the /dev/shm is part of the upper /dev tmpfs which is
mounted by the initial initrd ramdisk system before booting.  Therefore
no entry for /dev/shm is found in /etc/fstab nor required.

The kernel parameters can be changed by the user by editing the
variables in the "/etc/sysconfig/sapinit" configuration file.

Older versions of this package (including the package found in SLES 9
SP3 and SLES 10) had an init script called "/etc/init.d/sapr3" resp.
"/usr/sbin/rcsapr3".  This has been renamed to
"/etc/init.d/boot.sapconf" resp. "/usr/sbin/SAPconf", because R3 is not
really true nowadays anymore.

Also, the old script was supposed to be able to start up SAP R3
instances, when these were configured in the "/etc/sysconfig/sapr3"
file.	This configuration file has now been obsoleted. The new
"/etc/init.d/boot.sapconf" script delivered with this package does not
have the capability to start any SAP (R3) instances.  This
functionality has been replaced by the scripts delivered with the SAP
system itself.



Authors:
--------
    SUSE LINUX GmbH, 2007, Nuernberg, Germany, EU.

%prep
%setup -n %{name} -c -T

%build
echo 'int main () { return !(sizeof(void*) >= 8); }' | gcc -x c -o test64 -
if ./test64 ; then
  cp %{S:4} %{name}
%ifarch ia64
  PSZ=$(getconf PAGESIZE)
  PSZ=$(($PSZ>>10))
  SHMALL_OLD=$(grep -E '^SHMALL_MIN=' %{S:4})
  SHMALL_NEW=$(((${SHMALL_OLD#*=}*4)/${PSZ}))
  sed -ri "s/${SHMALL_OLD}/SHMALL_MIN=${SHMALL_NEW}/" %{name}
%endif
else
  cp %{S:3} %{name}
fi
rm -f ./test64
cp %{S:0} .
cp %{S:2} .
sed -ri 's|@@sapconf@@|%{name}|' boot.sapconf
sed -ri 's|@@confdir@@|%{_libdir}/%{name}|' boot.sapconf
sed -ri 's|@@funcdir@@|%{_libdir}/%{name}|' boot.sapconf
sed -ri 's|@@funcdir@@|%{_libdir}/%{name}|' functions

%install
mkdir -p %{buildroot}/var/adm/fillup-templates
mkdir -p %{buildroot}%{_sysconfdir}/init.d
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}%{_libdir}/%{name}/
mkdir -p %{buildroot}%{_sbindir}
install -m 0755 boot.sapconf	%{buildroot}%{_sysconfdir}/init.d/
install -m 0755 %{S:1}		%{buildroot}%{_sbindir}/
install -m 0444 functions	%{buildroot}%{_libdir}/%{name}/
install -m 0444 %{S:3}		%{buildroot}%{_libdir}/%{name}/
install -m 0444 %{S:4}		%{buildroot}%{_libdir}/%{name}/
install -m 0444 %{S:5}		%{buildroot}%{_docdir}/%{name}/
install -m 0444 %{S:6}		%{buildroot}%{_docdir}/%{name}/
install -m 0444 %{name}		%{buildroot}/var/adm/fillup-templates/sysconfig.%{name}
ln -sf %{_docdir}/%{name}/README %{buildroot}%{_libdir}/%{name}/
%if 0
%if "%name" != "sapconf"
# the old sapinit spec uses %%restart_on_update in %%postun
touch %{buildroot}%{_sysconfdir}/init.d/sapinit
touch %{buildroot}%{_sbindir}/SAPinit
%endif
%endif

%post
%{fillup_and_insserv -Y boot.sapconf}
# increase the value of MAX_MAP_COUNT_MIN to the new default, if already configured
scf=etc/sysconfig/sapinit
if test -e $scf; then
   awk -F= '{ if (($1==NAME)&&($2<NEW))  
		{printf "%s=%s\n",NAME,NEW} else { print $0 }} ' NAME=MAX_MAP_COUNT_MIN OLD=300000 NEW=1000000 $scf > $scf.tmp
	mv $scf.tmp $scf
fi
test ! -e /.buildenv || exit 0
%{restart_on_update boot.sapconf}

%postun
test ! -e /.buildenv || exit 0
%{insserv_cleanup}

%preun
test ! -e /.buildenv || exit 0
%{stop_on_removal boot.sapconf}
%if "%name" == "sapconf"
#

%triggerpostun -- sapinit < 3.0
sp='[[:space:]]+'
rc=etc/init.d/sapinit.rpmsave
mg="^#${sp}Copyright${sp}\(c\)${sp}1995-2005${sp}SAP${sp}AG${sp}Walldorf,${sp}Germany."
test -s ${rc} || exit 0
grep -qE "${mg}" ${rc} || exit 0
echo "Restore ${rc%%.rpmsave}: "
mv -v ${rc} ${rc%%.rpmsave}
%else
#

%triggerin -- sapinit < 3.0
# the old sapinit spec uses %%restart_on_update in %%postun
sb=usr/sbin/SAPinit
test -s ${sb} || exit 0
chmod u+w ${sb} || exit 0
echo '#!/bin/sh' > ${sb}
#

%if "%name" == "sapinit"

%triggerin -- sysstat
# enable and start, if required, the sysstat boot script
%{insserv_force_if_yast sysstat}
if test "$YAST_IS_RUNNING" != "instsys" -a ! -L /etc/cron.d/sysstat -a ! -e /etc/cron.d/sysstat ; then
    (/etc/init.d/sysstat check
     test $? -eq 3 && \
     /etc/init.d/sysstat start) > /dev/null 2>&1
fi
%endif

%triggerpostun -- sapinit < 3.0
sp='[[:space:]]+'
sb=usr/sbin/SAPinit
rc=etc/init.d/sapinit
mg="^#${sp}Copyright${sp}\(c\)${sp}1995-2005${sp}SAP${sp}AG${sp}Walldorf,${sp}Germany."
test -s ${rc} || exit 0
grep -qE "${mg}" ${rc} || rm -f ${rc}
test -s ${sb} || exit 0
rm -f ${sb}
#
%endif

%files 
%defattr(-,root,root)
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/LGPL
%{_docdir}/%{name}/README
%{_sbindir}/SAPconf
%config %{_sysconfdir}/init.d/boot.sapconf
%if 0
%if "%name" != "sapconf"
%ghost %config(missingok,noreplace) %{_sysconfdir}/init.d/sapinit
%ghost %config(missingok,noreplace) %{_sbindir}/SAPinit
%endif
%endif
%dir    %{_libdir}/%{name}
%{_libdir}/%{name}/functions
%{_libdir}/%{name}/config.b32
%{_libdir}/%{name}/config.b64
%{_libdir}/%{name}/README
/var/adm/fillup-templates/*

%changelog
* Wed Nov 17 2010 fabian.herschel@suse.de
- removed conflict to orarun (bnc#444333)
* Wed Sep 15 2010 dmueller@suse.de
- remove self-obsolete
* Thu Sep  2 2010 fabian@suse.de
- Changing the defeult of MAX_MAP_COUNT_MIN from 30000 to 1000000 even if its a package update (bnc#525824 and bnc#527935)
- Removing the empty start scripts sapinit and "binary" SAPinit, because build stopped with error
- Trigger sysstat to be activated when ever it is installed (trigger). sapinit is now compatible with sapconf for this trigger
* Wed May 26 2010 fabian.herschel@suse.de
- Override -1 for SHM with real unlimited (ULONG_MAX) (bnc#541775)
- Avoid to be fooled by `-1' for ULONG_MAX (bnc#556850)
- Increase MAX_MAP_COUNT_MIN from 300.000 to 1.000.000 (bnc#525824 and bnc#527935)
  all these fixes backported from sapconf (SLES11) to fix that also for sapinit
  (SLES10 and SLES9)
* Tue Mar 10 2009 werner@suse.de
- Remove vm.disable_cap_mlock and vm.hugetlb_shm_group (bnc#481496)
* Thu Oct 30 2008 werner@suse.de
- Ignore missing files in /proc/sys/ (bnc#440239)
* Wed Jul 23 2008 werner@suse.de
- Make sysstat a hard requirement (bnc#378356)
- Add sysctl parameter vm.disable_cap_mlock=1 (bnc#405094)
* Mon Jan 14 2008 werner@suse.de
- Force enabling service
* Fri Dec  7 2007 werner@suse.de
- Don't submit both sapconf and sapinit but only sapconf
* Wed Nov 28 2007 werner@suse.de
- Do not rename package for old distributions, use sapinit
- Avoid error messages from old sapinit in case of new sapinit
- Do not remove foreign sapinit rc script
* Mon Nov 26 2007 werner@suse.de
- Check max integer on 32bit platforms
- Add orarun to the conflicting packages
* Tue Nov 13 2007 werner@suse.de
- Rename spainit to spaconf
- Clean out old syssctl.conf from SAPinit
* Wed Nov  7 2007 werner@suse.de
- Add SAPINIT to Provides of boot.sapconf
- Add Suggests line with sysstat, cron, and logrotate
- If sysstat is installed boot.sapconf should depend on
* Mon Oct 29 2007 werner@suse.de
- Clean up and better error handling
* Fri Oct 26 2007 werner@suse.de
- New package sapinit from scratch version 3.0
* Fri Oct 19 2007 werner@suse.de
- More work on bug #280024
  * Make old sysctl.conf entries compact
  * Edit only modified parameters
* Wed Oct 17 2007 werner@suse.de
- Avoid multi line markers and avoid multi line entries for sysctl
  kernel parameters with vector values (bug #280024)
* Sat Sep  8 2007 DOlsson@Novell.com
- New version 2.0.2.
- The script "SAPinit" can now handle SLES 9 cases as well [#292314].
- Updated the description text in the ".spec" file.
  The text was made more clear with regards to the usage of the
  "/dev/shm" file system, as well as the various used script names.
  It now also covers the different behaviors for SLES 9 and SLES 10.
- Fixed issue under SLES 10, where a wrong sizing factoring was being
  used, when determining whether and how to do updates of the DEVSHM
  entry in FSTAB.
- Fixed issue under SLES 10, where DEVSHM got remounted, although
  there was not any reason to remount it.
* Thu Jul 12 2007 DOlsson@Novell.com
- Fixed various minor issues with the "susebuild" tag in
  "packaging/Makefile".
- Renamed "/etc/init.d/,/usr/sbin/rc}sapinit" to "sapconfig" in
  order to allow for SAP to make use of the name "sapinit" for
  their own start up script of the SAP system applications.
  [#292726 for SLES 9] and [#292727 for SLES 10].
- Updated the description text in ".spec" file to reflect the
  multiple usage of the package on SLES 9 and SLES 10.
  [#292726 for SLES 9] and [#292727 for SLES 10].
* Mon Jun 18 2007 DOlsson@Novell.com
- Removed wrong "Conflict:" statement.
* Wed May 16 2007 ro@suse.de
- remove "noarch" from specfile again.
  arch changes are not supported during SP update
* Tue May 15 2007 DOlsson@Novell.com
- Fixed specification issues in "*.spec" file with the tags
  "Provides:", "Obsoletes:", and "Conflicts:".
- Fixed issue with rearranging comments containing the "/dev/shm"
  string [#272721].
- Fixed typos in error messages issued by "SAPinit" script.
- Fixed setting of path name of the "sysconfigSAPinit" constant in
  the "SAPinit" script, when running in debugging mode.
* Tue May  8 2007 ro@suse.de
- change "test && foo" "if then foo fi" in postinstall (#272328)
* Mon May  7 2007 DOlsson@Novell.com
- In order to allow for initial system installation ([#269140] and
  [#269235]):
    + "Requires" and "Requires(post):" tags were rewritten.
    + Preventing "SAPinit" from being executed during post
    installtion.
* Fri May  4 2007 DOlsson@Novell.com
- In "SAPinit" do not use "-o mount", when only mounting the
  "/dev/shm" file system (option does not exist anymore).
- Added comments to "*.spec" file describing the usage of the
  "Provides:" tag.
- Further refined the "Provides:" and "Obsoletes:" tags.
* Thu May  3 2007 DOlsson@Novell.com
- Added instruct to stop building not needed debugging packages in
  Autobuild.
- Based on feedback from testers of the newest "sapinit" RPM package,
  the "Provides:" and "Obsoletes:" tags were refine.
- Added LSB mandentory "Short-Description:" tag to "sapinit".
* Sun Apr 22 2007 ro@suse.de
- use fillup as mandatory for sysconfig files
* Tue Apr 17 2007 DOlsson@Novell.com
- Updated ".spec" file to match that of the SUSE/Novell standards.
- Fixed "awk" output to stay in integer mode, when having huge
  figures for available virtual memory.
* Sat Apr 14 2007 DOlsson@Novell.com
- Using recommended instead of minimum value, if user has specified
  usage of "unlimited" (-1) for a parameter that does not allow
  this usage.
* Fri Apr 13 2007 DOlsson@Novell.com
- The "/etc/init.d/sapinit" script now provides "SAPINIT" instead
  of "SAP".
- Dropped "sh_opt" in "/etc/init.d/sapinit" (unknown command in
  "sh").
- In "SAPinit.sh":
  + Removed forgotten debug lines in "SAPinit.sh".
  + Prepared for option add-ons in lowering of info levels.
  + Cleaned up in information texts (making them more consistent).
  + Allowed for updating of "/etc/fstab" with actual found sizes
    instead of always using the recommended/minimum value.
  + Fixed bug in handling of the updating of "/etc/fstab", when
    "/dev/shm" is already mounted and big enough, but on entered
    in "/etc/fstab".
  + Now only activating the "/etc/sysctl.conf" parameters, when
    there is a real need for this.
- In the spec file:
  + Corrected the "Requires" to reflect what is really needed.
  + Expanded the "%%post" section with clean up facilities after the
    version 1.x series of this package.
  + Fixed a wrong setup of the "%%preun" section.
* Thu Apr 12 2007 DOlsson@Novell.com
- Updated spec file with newest required files the scripts need.
- Implemented the activation of the kernel parameters entered into
  the "/etc/sysctl.conf" file.
* Thu Apr  5 2007 DOlsson@Novell.com
- Implemented the settings of size in "/etc/fstab", when needed.
- Implemented the settings of the kernel parameters in
  "/etc/sysctl.conf", when needed.
- Updated the ".spec" file with more required commands.
- Clearified the description text in the ".spec" file (and thus in
  the README file, too).
* Fri Mar 30 2007 DOlsson@Novell.com
- Finished the last cleanups in the ".spec" file.
- Refined the "Makefile" to allow for building of needed files for
  the check-in into the SUSE/Novell build system.
- All fixes for the below mentioned bugzillas have now been implemented
  in accordance with the requirements from SAP (i.e. using recommended
  values, when nothing else specified, and allowing user to change the
  settings, but not under a certain minimum as specified by SAP):
    [#214311] Package "sapinit" sets shared memory too low
    [#197587] dedicated tmpfs /dev/shm does not exist anymore
    [#187387] "sapinit" sysctl settings for 64-bit architectures.
* Thu Mar 29 2007 DOlsson@Novell.com
- Fixed up the ".spec" file to be able to actually build the "sapinit"
  package.
- Created subdirectory "packaging" containing "Makefile" for easy
  packaging.
* Tue Mar 27 2007 DOlsson@Novell.com
- Reworked the "SAPinit.sh" script and "SAPinit" config file in order
  to be able to define the usage of recommended values (using 0) and
  in special cases "unlimited" (using -1).
- Updated the README file to match the ".spec" file.
- Added testing on "SAPinitDEBUG" to allow for reading of the
  "SAPinit" file from current directory.
- Added validation of the user defined parameters read from
  "/etc/sysconfig/SAPinit".
- Fixed the setting of the "SEM{MSL,MNS,OPM,MNI}_Cur" parameters.
- Documented the usage and hierarchy of "*_MIN[32]" and "*_ReV"
  parameters.
* Mon Mar 26 2007 DOlsson@Novell.com
- Reworked ".spec" file to now making use of a compressed TAR ball
  with the sources.
- Reworked ".spec" file in accordance with the "Packagers Manual"
  guidelines.
- Added "try-restart" as argument to "[rc]sapinit".
  Currently, it only maps to a "[rc]sapinit start".
- Updated copyright and author informations to the currently known
  correct state.
* Fri Mar 23 2007 DOlsson@Novell.com
- Added "/etc/sysconfig/SAPinit" allowing users to change the
  recommended values
- Updated the ".spec" file to only build for "noarch", while the
  scripts are architecture independed.
- Updated "SAPinit" to read the newly added "/etc/sysconfig/SAPinit"
  configuration file.
* Thu Mar 22 2007 DOlsson@Novell.com
- Renamed "sysctl-sapinit" to "SAPinit".
  Seemed to make sense, while the script is now handling a lot more
  than just setting the "sysctl" kernel parameters.
- Script completely reworked in order to be able to fullfil the SAP
  requirements for the functionality of the script.
- Script now contains hardcoded minimum and recommended values as
  defined by SAP for the various parameter values the script handles.
- Preparing script for usage of a "/etc/sysconfig/sapinit" file
  containing user defined values for the various settable parameters.
- Updated the ".spec" file to reflect the current state of the script.
* Fri Mar  9 2007 dhess@suse.de
- new version 2.0
- renamed rcsap to rcsapinit
- removed optional functionality to start SAP services at boot time automatically.
  This is usually done by using SAP mechanisms today, so not required in the OS.
- removed not longer needed sysconfig.sap and fillup macro
- removed obsolete symlinks rcsap and rcsapr3
- redirect debug info to syslog daemon (logger)
- removed SHMFS_SIZE from /etc/sysconfig/sap
  TMPFS dynamically calculated and configured in new script sysctl-sapinit
- added script sysctl-sapinit to set proper kernel paramters and to dynamically set and mount tmpfs
- removed obsolete sysctl.conf.* files
- removed obsolete script sysctl-wrapper
* Mon Sep  4 2006 stark@suse.de
- fixed fillup_and_insserv call
* Wed Aug  9 2006 stark@suse.de
- added SHMFS_SIZE to sysconfig/sapr3 and mount it via boot.sap
  service (#197587)
- only set higher sysctl values (#187387)
- renamed init script to sap
* Wed Jun 21 2006 stark@suse.de
- removed vm.heap-stack-gap as it doesn't exist in SLE10 (#186998)
* Tue Mar  7 2006 stark@suse.de
- bump version number to 1.1 (to indicate version for SLES10)
- don't install cron job for sysstat but suggest starting sysstat
  from init script (#154982)
- changed kernel.sem as requested (#135465)
* Mon Feb  6 2006 matz@suse.de
- Don't run sysctl in the build system.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Oct 24 2005 stark@suse.de
- changed values of kernel.sem
* Tue Oct 18 2005 stark@suse.de
- added LICENSE/COPYING file (#128699)
* Tue Oct 11 2005 stark@suse.de
- added vm.max_map_count parameter for all archs
* Mon Oct 10 2005 stark@suse.de
- renamed package to sapinit
- reversioned for initial autobuild checkin
* Thu Sep 29 2005 stark@suse.de
- create /etc/sysctl.conf.sap to avoid conflict with procps
- activate sapr3 init script by default to set sysctl
* Mon Aug  1 2005 stark@suse.de
- changed ppc64 settings on behalf of IBM
* Tue Jun 21 2005 stark@suse.de
- activated heap-stack setting for x86-64
* Fri Jan 21 2005 stark@suse.de
- added x86-64 architecture
* Wed Aug 25 2004 stark@suse.de
- added kernel.sem setting for all archs
* Wed Jul 21 2004 stark@suse.de
- added PPC64 architecture
- set shmfs size to 60%% for now
* Tue Feb 17 2004 stark@suse.de
- set arch dependency because of different requirements
  for kernel parameters
- added configuration for IA64
* Wed Apr 30 2003 stark@suse.de
- made /etc/sysctl.conf replaceable
* Fri Jan 24 2003 stark@suse.de
- bugfix for shmfs-size (was factor 100 too small :-()
* Thu Dec 12 2002 stark@suse.de
- added vm.heap-stack-gap to sysctl and set to 256
* Fri Oct 25 2002 stark@suse.de
- adopted for SLES8
* Fri May 17 2002 stark@suse.de
- added S/390 notes and increase shmmax to 2G
* Tue Sep  4 2001 stark@suse.de
- added msgmni settings (bjacke@suse.de)
